import 'package:sghi_core/app_wrapper/app_config.dart';
import 'package:sghi_core/app_wrapper/endpoints.dart';
import 'package:sghi_core/app_wrapper/enums.dart';

// ignore: avoid_classes_with_only_static_members
/// [EndpointContext] returns the correct server endpoint depending on the context
/// that the app is running on.
class EndpointContext {
  // Retrieves the GraphQL endpoint based on the AppConfig's environment
  static String getGraphQLEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdGraphqlEndpoint;
      case AppEnvironment.DEMO:
        return kDemoGraphqlEndpoint;
      case AppEnvironment.E2E:
        return ke2eGraphqlEndpoint;
      default:
        return kTestGraphqlEndpoint;
    }
  }

  // Retrieves the login by phone endpoint
  static String loginByPhoneEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdLoginByPhoneEndpoint;
      case AppEnvironment.DEMO:
        return kDemoLoginByPhoneEndpoint;
      case AppEnvironment.E2E:
        return ke2eLoginByPhoneEndpoint;
      default:
        return kTestLoginByPhoneEndpoint;
    }
  }

  // Retrieves the file upload endpoint
  static String uploadFileEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdUploadFileEndPoint;
      case AppEnvironment.DEMO:
        return kDemoUploadFileEndPoint;
      case AppEnvironment.E2E:
        return ke2eUploadFileEndPoint;
      default:
        return kTestUploadFileEndPoint;
    }
  }

  // Retrieves the PIN reset endpoint
  static String resetPinResetEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdPinResetEndpoint;
      case AppEnvironment.DEMO:
        return kDemoPinResetEndpoint;
      case AppEnvironment.E2E:
        return ke2ePinResetEndpoint;
      default:
        return kTestPinResetEndpoint;
    }
  }

  // Retrieves the user PIN update endpoint
  static String updateUserPinEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdUpdateUserPinEndpoint;
      case AppEnvironment.DEMO:
        return kDemoUpdateUserPinEndpoint;
      case AppEnvironment.E2E:
        return ke2eUpdateUserPinEndpoint;
      default:
        return kTestUpdateUserPinEndpoint;
    }
  }

  // Retrieves the phone number verification endpoint
  static String verifyPhoneEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdVerifyPhoneEndpoint;
      case AppEnvironment.DEMO:
        return kDemoVerifyPhoneEndpoint;
      case AppEnvironment.E2E:
        return ke2eVerifyPhoneEndpoint;
      default:
        return kTestVerifyPhoneEndpoint;
    }
  }

  // Retrieves the user creation by phone endpoint
  static String createUserByPhoneEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdCreateUserByPhoneEndpoint;
      case AppEnvironment.DEMO:
        return kDemoCreateUserByPhoneEndpoint;
      case AppEnvironment.E2E:
        return ke2eCreateUserByPhoneEndpoint;
      default:
        return kTestCreateUserByPhoneEndpoint;
    }
  }

  // Retrieves the OTP resend endpoint
  static String retrySendOtpEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdRetryResendOtpEndpoint;
      case AppEnvironment.DEMO:
        return kDemoRetryResendOtpEndpoint;
      case AppEnvironment.E2E:
        return ke2eRetryResendOtpEndpoint;
      default:
        return kTestRetryResendOtpEndpoint;
    }
  }

  // Retrieves the token refresh endpoint
  static String refreshTokenEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdRefreshTokenEndpoint;
      case AppEnvironment.DEMO:
        return kDemoRefreshTokenEndpoint;
      case AppEnvironment.E2E:
        return ke2eRefreshTokenEndpoint;
      default:
        return kTestRefreshTokenEndpoint;
    }
  }

  // Retrieves the anonymous login endpoint
  static String anonymousLoginEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdAnonymousLoginEndpoint;
      case AppEnvironment.DEMO:
        return kDemoAnonymousLoginEndpoint;
      case AppEnvironment.E2E:
        return ke2eAnonymousLoginEndpoint;
      default:
        return kTestAnonymousLoginEndpoint;
    }
  }

  // Retrieves the user recovery phone numbers endpoint
  static String userRecoveryPhoneNumbers(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdUserRecoveryPhoneNumbersEndpoint;
      case AppEnvironment.DEMO:
        return kDemoUserRecoveryPhoneNumbersEndpoint;
      case AppEnvironment.E2E:
        return ke2eUserRecoveryPhoneNumbersEndpoint;
      default:
        return kTestUserRecoveryPhoneNumbersEndpoint;
    }
  }

  // Retrieves the account recovery OTP sending endpoint
  static String sendRecoverAccountOTP(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdSendRecoverAccountOtpEndpoint;
      case AppEnvironment.DEMO:
        return kDemoSendRecoverAccountOtpEndpoint;
      case AppEnvironment.E2E:
        return ke2eSendRecoverAccountOtpEndpoint;
      default:
        return kTestSendRecoverAccountOtpEndpoint;
    }
  }

  // Retrieves the primary phone number setting endpoint
  static String setPrimaryPhoneNumber(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdSetPrimaryPhoneNumberEndpoint;
      case AppEnvironment.DEMO:
        return kDemoSetPrimaryPhoneNumberEndpoint;
      case AppEnvironment.E2E:
        return ke2eSetPrimaryPhoneNumberEndpoint;
      default:
        return kTestSetPrimaryPhoneNumberEndpoint;
    }
  }

  // Retrieves the flagged features switching endpoint
  static String switchFlaggedFeaturesEndpoint(AppConfig context) {
    switch (context.environment) {
      case AppEnvironment.PROD:
        return kProdSwitchFlaggedFeaturesEndpoint;
      case AppEnvironment.DEMO:
        return kDemoSwitchFlaggedFeaturesEndpoint;
      case AppEnvironment.E2E:
        return ke2eSwitchFlaggedFeaturesEndpoint;
      default:
        return kTestSwitchFlaggedFeaturesEndpoint;
    }
  }
}
