import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/app_wrapper/app_config.dart';
import 'package:sghi_core/app_wrapper/enums.dart';

void main() {
  group('AppConfig Initialization', () {
    // Testing BEWELL variant initializations
    test('BEWELL variant is initialized with correct environments', () {
      expect(bewellTest.variant, equals(AppVariant.BEWELL));
      expect(bewellTest.environment, equals(AppEnvironment.TEST));

      expect(bewellDemo.variant, equals(AppVariant.BEWELL));
      expect(bewellDemo.environment, equals(AppEnvironment.DEMO));

      expect(bewellProd.variant, equals(AppVariant.BEWELL));
      expect(bewellProd.environment, equals(AppEnvironment.PROD));

      expect(bewellE2E.variant, equals(AppVariant.BEWELL));
      expect(bewellE2E.environment, equals(AppEnvironment.E2E));
    });

    // Testing SLADE360ADVANTAGE variant initializations
    test('SLADE360ADVANTAGE variant is initialized with correct environments',
        () {
      expect(
          slade360AdvantageTest.variant, equals(AppVariant.SLADE360ADVANTAGE));
      expect(slade360AdvantageTest.environment, equals(AppEnvironment.TEST));

      expect(
          slade360AdvantageDemo.variant, equals(AppVariant.SLADE360ADVANTAGE));
      expect(slade360AdvantageDemo.environment, equals(AppEnvironment.DEMO));

      expect(
          slade360AdvantageProd.variant, equals(AppVariant.SLADE360ADVANTAGE));
      expect(slade360AdvantageProd.environment, equals(AppEnvironment.PROD));

      expect(
          slade360AdvantageE2E.variant, equals(AppVariant.SLADE360ADVANTAGE));
      expect(slade360AdvantageE2E.environment, equals(AppEnvironment.E2E));
    });

    // Testing MYCAREHUB variant initializations
    test('MYCAREHUB variant is initialized with correct environments', () {
      expect(myCareHubTest.variant, equals(AppVariant.MYCAREHUB));
      expect(myCareHubTest.environment, equals(AppEnvironment.TEST));

      expect(myCareHubDemo.variant, equals(AppVariant.MYCAREHUB));
      expect(myCareHubDemo.environment, equals(AppEnvironment.DEMO));

      expect(myCareHubProd.variant, equals(AppVariant.MYCAREHUB));
      expect(myCareHubProd.environment, equals(AppEnvironment.PROD));

      expect(myCareHubE2E.variant, equals(AppVariant.MYCAREHUB));
      expect(myCareHubE2E.environment, equals(AppEnvironment.E2E));
    });

    // Testing MYCAREHUBDAKTARI variant initializations
    test('MYCAREHUBDAKTARI variant is initialized with correct environments',
        () {
      expect(myCareHubDaktariTest.variant, equals(AppVariant.MYCAREHUBDAKTARI));
      expect(myCareHubDaktariTest.environment, equals(AppEnvironment.TEST));

      expect(myCareHubDaktariDemo.variant, equals(AppVariant.MYCAREHUBDAKTARI));
      expect(myCareHubDaktariDemo.environment, equals(AppEnvironment.DEMO));

      expect(myCareHubDaktariProd.variant, equals(AppVariant.MYCAREHUBDAKTARI));
      expect(myCareHubDaktariProd.environment, equals(AppEnvironment.PROD));

      expect(myCareHubDaktariE2E.variant, equals(AppVariant.MYCAREHUBDAKTARI));
      expect(myCareHubDaktariE2E.environment, equals(AppEnvironment.E2E));
    });

    // Testing UONAFYAPP360 variant initializations
    test('UONAFYAPP360 variant is initialized with correct environments', () {
      expect(uonAfyaApp360Test.variant, equals(AppVariant.UONAFYAPP360));
      expect(uonAfyaApp360Test.environment, equals(AppEnvironment.TEST));

      expect(uonAfyaApp360Demo.variant, equals(AppVariant.UONAFYAPP360));
      expect(uonAfyaApp360Demo.environment, equals(AppEnvironment.DEMO));

      expect(uonAfyaApp360Prod.variant, equals(AppVariant.UONAFYAPP360));
      expect(uonAfyaApp360Prod.environment, equals(AppEnvironment.PROD));

      expect(uonAfyaApp360E2E.variant, equals(AppVariant.UONAFYAPP360));
      expect(uonAfyaApp360E2E.environment, equals(AppEnvironment.E2E));
    });

    // Testing UONAFYAPP360DAKTARI variant initializations
    test('UONAFYAPP360DAKTARI variant is initialized with correct environments',
        () {
      expect(uonAfyaApp360DaktariTest.variant,
          equals(AppVariant.UONAFYAPP360DAKTARI));
      expect(uonAfyaApp360DaktariTest.environment, equals(AppEnvironment.TEST));

      expect(uonAfyaApp360DaktariDemo.variant,
          equals(AppVariant.UONAFYAPP360DAKTARI));
      expect(uonAfyaApp360DaktariDemo.environment, equals(AppEnvironment.DEMO));

      expect(uonAfyaApp360DaktariProd.variant,
          equals(AppVariant.UONAFYAPP360DAKTARI));
      expect(uonAfyaApp360DaktariProd.environment, equals(AppEnvironment.PROD));

      expect(uonAfyaApp360DaktariE2E.variant,
          equals(AppVariant.UONAFYAPP360DAKTARI));
      expect(uonAfyaApp360DaktariE2E.environment, equals(AppEnvironment.E2E));
    });
  });
  group('AppConfig Equality and Hash Code', () {
    test('AppConfig instances with identical properties are equal', () {
      const AppConfig config1 = AppConfig(
          variant: AppVariant.BEWELL, environment: AppEnvironment.TEST);
      const AppConfig config2 = AppConfig(
          variant: AppVariant.BEWELL, environment: AppEnvironment.TEST);

      expect(config1, equals(config2));
      expect(config1 == config2, isTrue);
      expect(config1.hashCode, equals(config2.hashCode));
    });

    test('AppConfig instances with different properties are not equal', () {
      const AppConfig config1 = AppConfig(
          variant: AppVariant.BEWELL, environment: AppEnvironment.TEST);
      const AppConfig config2 = AppConfig(
          variant: AppVariant.BEWELL, environment: AppEnvironment.DEMO);

      expect(config1, isNot(equals(config2)));
      expect(config1 == config2, isFalse);
    });

    test(
        'AppConfig instances maintain consistency between equality and hash code',
        () {
      const AppConfig config1 = AppConfig(
          variant: AppVariant.BEWELL, environment: AppEnvironment.TEST);
      const AppConfig config2 = AppConfig(
          variant: AppVariant.BEWELL, environment: AppEnvironment.TEST);
      const AppConfig config3 = AppConfig(
          variant: AppVariant.BEWELL, environment: AppEnvironment.DEMO);

      // If two objects are equal according to the equals method, then calling the hashCode
      // method on each of the two objects must produce the same integer result.
      if (config1 == config2) {
        expect(config1.hashCode, equals(config2.hashCode));
      }

      // If two objects are not equal according to the equals method, then calling the hashCode
      // method on each of the two objects do not need to produce distinct integer results.
      // However, programmers should be aware that producing distinct integer results
      // for unequal objects may improve the performance of hash tables.
      if (config1 != config3) {
        expect(config1.hashCode, isNot(equals(config3.hashCode)));
      }
    });
  });
}
